]> git.sesse.net Git - stockfish/blobdiff - src/tt.h
Prefer int to uint8_t when possible
[stockfish] / src / tt.h
index 0b95ea635997d87f7b999917951f24d2be90ad21..ff1cb910f63035d1d9582fe652d9c91171dc521d 100644 (file)
--- a/src/tt.h
+++ b/src/tt.h
@@ -43,7 +43,7 @@
 /// bit 64-79: value
 /// bit 80-95: depth
 /// bit 96-111: static value
/// bit 112-127: king danger value
 ///
 /// the 32 bits of the data field are so defined
 ///
@@ -62,8 +62,9 @@ public:
       value16     = int16_t(v);
       depth16     = int16_t(d);
       staticValue = int16_t(statV);
-      kingDanger  = int16_t(kd);
+      staticValueMargin  = int16_t(kd);
   }
+  void set_generation(int g) { data = move() | (type() << 21) | (g << 23); }
 
   uint32_t key() const { return key32; }
   Depth depth() const { return Depth(depth16); }
@@ -72,7 +73,7 @@ public:
   ValueType type() const { return ValueType((data >> 21) & 3); }
   int generation() const { return data >> 23; }
   Value static_value() const { return Value(staticValue); }
-  Value king_danger() const { return Value(kingDanger); }
+  Value static_value_margin() const { return Value(staticValueMargin); }
 
 private:
   uint32_t key32;
@@ -80,7 +81,7 @@ private:
   int16_t value16;
   int16_t depth16;
   int16_t staticValue;
-  int16_t kingDanger;
+  int16_t staticValueMargin;
 };
 
 
@@ -102,6 +103,9 @@ struct TTCluster {
 
 class TranspositionTable {
 
+  TranspositionTable(const TranspositionTable&);
+  TranspositionTable& operator=(const TranspositionTable&);
+
 public:
   TranspositionTable();
   ~TranspositionTable();
@@ -111,11 +115,12 @@ public:
   TTEntry* retrieve(const Key posKey) const;
   void new_search();
   TTEntry* first_entry(const Key posKey) const;
+  void refresh(const TTEntry* tte) const;
 
 private:
   size_t size;
   TTCluster* entries;
-  uint8_t generation;
+  int generation;
 };
 
 extern TranspositionTable TT;
@@ -130,4 +135,13 @@ inline TTEntry* TranspositionTable::first_entry(const Key posKey) const {
   return entries[uint32_t(posKey) & (size - 1)].data;
 }
 
+
+/// TranspositionTable::refresh updates the 'generation' value of the TTEntry
+/// to avoid aging. Normally called after a TT hit, before to return.
+
+inline void TranspositionTable::refresh(const TTEntry* tte) const {
+
+  const_cast<TTEntry*>(tte)->set_generation(generation);
+}
+
 #endif // !defined(TT_H_INCLUDED)
@@ -43,7 +43,7 @@
 /// bit 80-95: depth
 /// bit 96-111: static value
-/// bit 112-127: king danger value
+/// bit 112-127: margin of static value
 ///
 /// the 32 bits of the data field are so defined